%% File `xoblivoir.cls` = alias of oblivoir.cls
%%
%% (C) Copyright 2006-2025 Kangsoo Kim <modviv2k15 at gmail com>
%% (C) Copyright 2013      Kihwang Lee <leekh at ktug org>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%  http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2006/05/20 or later.
%%
%% Read LICENSE included in the package.
%%
%% --------------------------------------------------------
%% oblivoir.cls

\ProvidesClass{xoblivoir}

\LoadClassWithOptions{oblivoir}

\endinput
